==> mongodb-7.0.23.gh.tar.gz: mongo-r7.0.23/src/mongo/s/analyze_shard_key_role.h <==
/**
 *    Copyright (C) 2023-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/operation_context.h"
#include "mongo/platform/basic.h"

namespace mongo {
namespace analyze_shard_key {

bool isFeatureFlagEnabled(bool ignoreFCV = false);

bool supportsCoordinatingQueryAnalysis(bool isReplEnabled, bool ignoreFCV = false);
bool supportsCoordinatingQueryAnalysis(OperationContext* opCtx, bool ignoreFCV = false);

bool supportsPersistingSampledQueries(bool isReplEnabled, bool ignoreFCV = false);
bool supportsPersistingSampledQueries(OperationContext* opCtx, bool ignoreFCV = false);

bool supportsSamplingQueries(bool isReplEnabled, bool ignoreFCV = false);
bool supportsSamplingQueries(OperationContext* opCtx, bool ignoreFCV = false);
bool supportsSamplingQueries(ServiceContext* serviceContext, bool ignoreFCV = false);

}  // namespace analyze_shard_key
}  // namespace mongo

==> mongodb-8.0.8.gh.tar.gz: mongo-r8.0.8/src/mongo/s/analyze_shard_key_role.h <==
/**
 *    Copyright (C) 2023-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/operation_context.h"
#include "mongo/db/service_context.h"
#include "mongo/platform/basic.h"

namespace mongo {
namespace analyze_shard_key {

bool isFeatureFlagEnabled(bool ignoreFCV = false);

bool supportsCoordinatingQueryAnalysis(bool isReplEnabled);
bool supportsCoordinatingQueryAnalysis(OperationContext* opCtx);

bool supportsPersistingSampledQueries(bool isReplEnabled);
bool supportsPersistingSampledQueries(OperationContext* opCtx);

bool supportsSamplingQueries(bool isReplEnabled);
bool supportsSamplingQueries(OperationContext* opCtx);
bool supportsSamplingQueries(ServiceContext* serviceContext);

}  // namespace analyze_shard_key
}  // namespace mongo
